@@ -40,10 +40,11 @@ metadata = {'creator': {'name': 'Unknown',
                             },
             'reduction': {'software': {'name': 'islatu',
                                        'link': 'https://islatu.readthedocs.io',
-                                       'version': '0.0.40'},
+                                       'version': '0.0.41'},
                           'yaml': 'Unknown',
                           'input files': {'datafiles': []},
-                          'data state': {}}
+                          'data state': {}},
+            'data': {}
             }
 
 class Foreperson:
